# from padie.core.language import detect_language
# from padie.core.intent import detect_intent

# __all__ = ["detect_language", "detect_intent"]

from .language_detector import LanguageDetector

__all__ = ["LanguageDetector"]